<?php
/**
 * functions.php
 *
 * The theme's functions and definitions.
 */

/**
 * ----------------------------------------------------------------------------------------
 * 1.0 - Define constants.
 * ----------------------------------------------------------------------------------------
 */
define( 'THEMEROOT', get_stylesheet_directory_uri() );
define( 'IMAGES', THEMEROOT . '/images' );
define( 'SCRIPTS', THEMEROOT . '/js' );


/**
 * ----------------------------------------------------------------------------------------
 * 4.0 - Set up theme default and register various supported features.
 * ----------------------------------------------------------------------------------------
 */

if ( ! function_exists( 'alpha_setup' ) ) {
	function alpha_setup() {
		/**
		 * Make the theme available for translation.
		 */
		$lang_dir = THEMEROOT . '/languages';
		load_theme_textdomain( 'alpha', $lang_dir );

		/**
		 * Add support for post formats.
		 */
		add_theme_support( 'post-formats',
			array(
				'gallery',
				'link',
				'image',
				'quote',
				'video',
				'audio'
			)
		);

		/**
		 * Add support for automatic feed links.
		 */
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'widgets' );

		/**
		 * Add support for post thumbnails.
		 */
		add_theme_support( 'post-thumbnails' );


		/**
		 * Register nav menus.
		 */
		register_nav_menus(
			array(
				'main-menu'    => __( 'القائمة الرئيسية', 'alpha' ),
				'footer-menu1' => __( 'قائمة الفوتر1 ', 'alpha' ),
				'footer-menu2' => __( 'قائمة الفوتر2 ', 'alpha' ),
				'footer-menu3' => __( 'قائمة الفوتر3 ', 'alpha' ),
				'footer-menu4' => __( 'قائمة الفوتر4 ', 'alpha' ),
				'footer-menu5' => __( 'قائمة الفوتر5 ', 'alpha' ),
				'footer-menu6' => __( 'قائمة الفوتر6 ', 'alpha' )
			)
		);
	}

	add_action( 'after_setup_theme', 'alpha_setup' );
}


/**
 * ----------------------------------------------------------------------------------------
 * 8.0 - Function that validates a field's length.
 * ----------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'alpha_validate_length' ) ) {
	function alpha_validate_length( $fieldValue, $minLength ) {
		// First, remove trailing and leading whitespace
		return ( strlen( trim( $fieldValue ) ) > $minLength );
	}
}


/**
 * ----------------------------------------------------------------------------------------
 * 10.0 - Load the custom scripts for the theme.
 * ----------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'alpha_scripts' ) ) {
	function alpha_scripts() {
		// Adds support for pages with threaded comments
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		// Register scripts
		wp_register_script( 'bootstrap-js', SCRIPTS . '/bootstrap.min.js', array( 'jquery' ), false, true );
//		wp_register_script( 'wow-js', SCRIPTS . '/wow.min.js', array( 'jquery' ), false, true );
//		wp_register_script( 'hoverdir', SCRIPTS . '/jquery.hoverdir.js', array( 'jquery' ), false, true );
//		wp_register_script( 'modernizr', SCRIPTS . '/modernizr.custom.97074.js', array( 'jquery' ), false, true );
//		wp_register_script( 'owlcarousel', SCRIPTS . '/owl.carousel.min.js', array( 'jquery' ), false, true );
//		wp_register_script( 'news', SCRIPTS . '/jquery.ticker.js', array( 'jquery' ), false, true );


		// Load the custom scripts
		wp_enqueue_script( 'bootstrap-js' );
//		wp_enqueue_script( 'wow-js' );
//		wp_enqueue_script( 'hoverdir' );
//		wp_enqueue_script( 'modernizr' );
//		wp_enqueue_script( 'owlcarousel' );
//		wp_enqueue_script( 'news' );
		if ( ! is_rtl() ) {
			wp_register_script( 'custom-en', SCRIPTS . '/custom-en.js', array( 'jquery' ), false, true );
			wp_enqueue_script( 'custom-en' );

		}else {
			wp_register_script( 'custom', SCRIPTS . '/custom.js', array( 'jquery' ), false, true );
			wp_enqueue_script( 'custom' );

		}
		// Load the stylesheets
		wp_enqueue_style( 'bootstrap', THEMEROOT . '/css/bootstrap.min.css' );
//		wp_enqueue_style( 'bootstrapthemes', THEMEROOT . '/css/bootstrap-theme.min.css' );
		wp_enqueue_style( 'Fontawesome', THEMEROOT . '/css/font-awesome.min.css' );
//		wp_enqueue_style( 'animate', THEMEROOT . '/css/animate.css' );
//		wp_enqueue_style( 'owl.carousel', THEMEROOT . '/css/owl.carousel.css' );
//		wp_enqueue_style( 'sinister', THEMEROOT . '/css/sinister.css' );

		if ( is_rtl() ) {

			wp_enqueue_style( 'bootstrap-rtl', THEMEROOT . '/css/bootstrap-rtl.min.css' );
			wp_enqueue_style( 'rtl', THEMEROOT . '/style.css' );

		} else {
			wp_enqueue_style( 'en', THEMEROOT . '/en.css' );
		}

	}

	add_action( 'wp_enqueue_scripts', 'alpha_scripts' );
}


/**
 * ----------------------------------------------------------------------------------------
 * 11.0 - Custom Post Type.
 * ----------------------------------------------------------------------------------------
 */


register_post_type( 'slider', array(
	'public'              => true,
	'hierarchical'        => false,
	'exclude_from_search' => false,
	'has_archive'         => false,
	'rewrite'             => array( 'slug' => 'slider' ),
	'capability_type'     => 'post',
	'taxonomies'          => array( 'post_tag' ),
	'labels'              => array(
		'name'               => 'السلايدر',
		'add_new_item'       => 'إضافة سلايدر',
		'singular_name'      => 'السلايدر',
		'menu_name'          => 'السلايدر',
		'name_admin_bar'     => 'سلايدر',
		'all_items'          => 'كافة السلايدر',
		'add_new'            => 'إضافة سلايدر',
		'edit_item'          => 'تحرير السلايدر',
		'new_item'           => 'سلايدر جديدة',
		'view_item'          => 'مشاهدة السلايدر',
		'search_items'       => 'البحث عن سلايدر',
		'not_found'          => 'لا يوجد سلايدرات.',
		'not_found_in_trash' => 'لا يوجد سلايدرات',
		'parent_item_colon'  => 'القسم الرئيسى'
	),
	'supports'            => array( 'title', 'thumbnail', 'editor' )
) );

register_post_type( 'services', array(
	'public'              => true,
	'hierarchical'        => false,
	'exclude_from_search' => false,
	'has_archive'         => false,
	'rewrite'             => array( 'slug' => 'services' ),
	'capability_type'     => 'post',
	'taxonomies'          => array( 'post_tag' ),
	'labels'              => array(
		'name'               => 'خدماتنا',
		'add_new_item'       => 'إضافة خدمة',
		'singular_name'      => 'خدماتنا',
		'menu_name'          => 'خدماتنا',
		'name_admin_bar'     => 'خدمة',
		'all_items'          => 'كافة خدماتنا',
		'add_new'            => 'إضافة خدمة',
		'edit_item'          => 'تحرير خدماتنا',
		'new_item'           => 'خدمة جديد',
		'view_item'          => 'مشاهدة خدماتنا',
		'search_items'       => 'البحث عن خدمة',
		'not_found'          => 'لا يوجد خدمة.',
		'not_found_in_trash' => 'لا يوجد خدمة',
		'parent_item_colon'  => 'القسم الرئيسى'
	),
	'supports'            => array( 'title', 'thumbnail', 'editor', 'comments' )
) );


/*************************************************/
/* Sizes */
/*************************************************/

add_image_size( 'slider-image', 1650, 614, true );
add_image_size( 'serv-img', 260, 180, true );



/*************************************************/
/* Page Option */
/*************************************************/

if ( function_exists( 'acf_add_options_page' ) ) {

	acf_add_options_page( array(
		'page_title' => 'اعدادات القالب',
		'menu_title' => 'اعدادات القالب',
		'menu_slug'  => 'theme-general-settings',
		'capability' => 'edit_posts',
		'redirect'   => false
	) );

}


//function news_index($query) {
//	if (!is_admin() && $query->is_main_query() ) {
//		if ($query->is_home()) {
//			$query->set('post_type', 'page');
//			$query->set('post__not_in', array( 5, 7, 9 ));
//			$query->set('posts_per_page' , get_field( 'posts-num', 'options' ));
//		}
//	}
//}
//add_action('pre_get_posts', 'news_index');